@@ -93,10 +93,14 @@ DATABASES = {
     },
 }
 
+REDIS_HOST = config("REDIS_HOST", cast=str, default="127.0.0.1")
+REDIS_PORT = config("REDIS_PORT", cast=int, default=6379)
+REDIS_DB = config("REDIS_DATABASE", cast=int, default=0)
+
 CACHES = {
     "default": {
         "BACKEND": "django_redis.cache.RedisCache",
-        "LOCATION": config("FULL_REDIS_HOST", default="redis://127.0.0.1:6379"),
+        "LOCATION": f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}",
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
         },
@@ -165,7 +169,7 @@ REST_FRAMEWORK = {
 SPECTACULAR_SETTINGS = {
     "TITLE": "melon-translate",
     "DESCRIPTION": "Translation microservice",
-    "VERSION": "0.7.2",
+    "VERSION": "0.7.3",
 }
 
 BATON = {
