@@ -1,8 +1,11 @@
+import hashlib
 import json
+from datetime import datetime
 
 from django.db.models import Q
 from django.utils.decorators import method_decorator
 from django.views.decorators.cache import cache_page
+from django.views.decorators.http import condition
 from django.views.decorators.vary import vary_on_cookie
 from django.views.generic import TemplateView
 from health_check.views import MainView
@@ -21,6 +24,18 @@ from translate.service.serializers import (
 )
 
 
+def last_modified(request, *args, **kwargs) -> datetime:
+    latest_time = Translation.objects.order_by("-modified").first().modified
+    return latest_time
+
+
+def entity_tag(request, *args, **kwargs) -> hash:
+    try:
+        return hashlib.md5(":".join(request.GET.dict().values()).encode("utf-8")).hexdigest()
+    except UnicodeEncodeError:
+        return hashlib.md5(":".join(request.GET.dict().values()).encode("ascii")).hexdigest()
+
+
 class TranslationsAPIView(ListAPIView):
     """
     This view should return a list of translations
@@ -33,6 +48,7 @@ class TranslationsAPIView(ListAPIView):
 
     @method_decorator(vary_on_cookie)
     @method_decorator(cache_page(CACHE_TTL))
+    @method_decorator(condition(etag_func=entity_tag, last_modified_func=last_modified))
     def get(self, request, *args, **kwargs):
 
         data = {
@@ -63,7 +79,7 @@ class TranslationsAPIView(ListAPIView):
         if snake_keys:
             query &= Q(key__snake_name__in=snake_keys)
 
-        data = self.paginate_queryset(self.queryset.filter(query))
+        data = self.paginate_queryset(self.queryset.filter(query).order_by("-modified"))
 
         tran_serializer = TranslationSerializer(data, many=True)
         paginated_response = self.get_paginated_response(tran_serializer.data)
